@@ -1,62 +1,68 @@
 package Net::CLI::Interact::Transport::Serial;
 {
-  $Net::CLI::Interact::Transport::Serial::VERSION = '1.122530';
+  $Net::CLI::Interact::Transport::Serial::VERSION = '2.123300_001';
 }
 
-use Moose;
-extends 'Net::CLI::Interact::Transport';
+use Moo;
+use Sub::Quote;
+use MooX::Types::MooseLike::Base qw(InstanceOf);
+
+extends 'Net::CLI::Interact::Transport::Base';
 
 {
     package # hide from pause
         Net::CLI::Interact::Transport::Serial::Options;
-    use Moose;
-    use Moose::Util::TypeConstraints qw(enum);
+
+    use Moo;
+    use Sub::Quote;
+    use MooX::Types::MooseLike::Base qw(Str Bool Int ArrayRef Any);
+
     extends 'Net::CLI::Interact::Transport::Options';
 
     has 'device' => (
         is => 'rw',
-        isa => 'Str',
+        isa => Str,
         required => 1,
     );
 
     has 'parity' => (
         is => 'rw',
-        isa => enum([qw/none even odd/]);
-        default => 'none',
-        required => 0,
+        isa => quote_sub(
+            q{ die "$_[0] not none/even/odd" unless $_[0] =~ m/^(?:none|even|odd)$/ }),
+        default => quote_sub(q{'none'}),
     );
 
     has 'nostop' => (
         is => 'rw',
-        isa => 'Bool',
-        default => 0,
-        required => 0,
+        isa => Bool,
+        default => quote_sub('0'),
     );
 
     has 'speed' => (
         is => 'rw',
-        isa => 'Int',
-        default => 9600,
-        required => 0,
+        isa => Int,
+        default => quote_sub('9600'),
     );
 
-    use Moose::Util::TypeConstraints;
-    coerce 'Net::CLI::Interact::Transport::Serial::Options'
-        => from 'HashRef[Any]'
-            => via { Net::CLI::Interact::Transport::Serial::Options->new($_) };
+    has 'opts' => (
+        is => 'rw',
+        isa => ArrayRef[Any],
+        default => sub { [] },
+    );
 }
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 has 'connect_options' => (
     is => 'ro',
-    isa => 'Net::CLI::Interact::Transport::Serial::Options',
-    coerce => 1,
+    isa => InstanceOf['Net::CLI::Interact::Transport::Serial::Options'],
+    coerce => quote_sub(q{ (ref '' eq ref $_[0]) ? $_[0] :
+        Net::CLI::Interact::Transport::Serial::Options->new(@_) }),
     required => 1,
 );
 
 sub _build_app {
     my $self = shift;
-    confess "please pass location of plink.exe in 'app' parameter to new()\n"
+    die "please pass location of plink.exe in 'app' parameter to new()\n"
         if $self->is_win32;
     return 'cu'; # unix
 }
@@ -65,7 +71,11 @@ sub runtime_options {
     my $self = shift;
 
     if ($self->is_win32) {
-        return ('-serial',);
+        return (
+            '-serial',
+            @{$self->connect_options->opts},
+            $self->connect_options->device,
+        );
     }
     else {
         return (
@@ -73,6 +83,7 @@ sub runtime_options {
             ('-l ' . $self->connect_options->device),
             ('-s ' . $self->connect_options->speed),
             ($self->connect_options->nostop ? '--nostop' : ()),
+            @{$self->connect_options->opts},
         );
     }
 }
@@ -91,9 +102,9 @@ Net::CLI::Interact::Transport::Serial - Serial-line based CLI connection
 
 =head1 VERSION
 
-version 1.122530
+version 2.123300_001
 
-=head1 DECRIPTION
+=head1 DESCRIPTION
 
 This module provides a wrapped instance of a Serial-line client for use by
 L<Net::CLI::Interact>.
@@ -137,6 +148,12 @@ value.
 You can set the speed (or I<baud rate>) of the serial line by passing a value
 to this named parameter. The default is C<9600>.
 
+=item opts
+
+If you want to pass any other options to the application, then use
+this option, which should be an array reference. Each item in the list will be
+passed to the application, separated by a single space character.
+
 =item reap
 
 Only used on Unix platforms, this installs a signal handler which attempts to
@@ -153,7 +170,7 @@ See the following for further interface details:
 
 =item *
 
-L<Net::CLI::Interact::Transport>
+L<Net::CLI::Interact::Transport::Base>
 
 =back
 
