@@ -1,61 +1,62 @@
 package Net::CLI::Interact::Transport::Telnet;
 {
-  $Net::CLI::Interact::Transport::Telnet::VERSION = '1.122530';
+  $Net::CLI::Interact::Transport::Telnet::VERSION = '2.123300_001';
 }
 
-use Moose;
-extends 'Net::CLI::Interact::Transport';
+use Moo;
+use Sub::Quote;
+use MooX::Types::MooseLike::Base qw(InstanceOf);
+
+extends 'Net::CLI::Interact::Transport::Base';
 
 {
     package # hide from pause
         Net::CLI::Interact::Transport::Telnet::Options;
-    use Moose;
+
+    use Moo;
+    use Sub::Quote;
+    use MooX::Types::MooseLike::Base qw(Str Int ArrayRef Any);
+
     extends 'Net::CLI::Interact::Transport::Options';
 
     has 'host' => (
         is => 'rw',
-        isa => 'Str',
+        isa => Str,
         required => 1,
     );
 
     has 'port' => (
         is => 'rw',
-        isa => 'Int',
-        required => 0,
-        default => 23,
+        isa => Int,
+        default => quote_sub('23'),
     );
 
     has 'opts' => (
         is => 'rw',
-        isa => 'ArrayRef[Any]',
-        required => 0,
+        isa => ArrayRef[Any],
         default => sub { [] },
     );
-
-    use Moose::Util::TypeConstraints;
-    coerce 'Net::CLI::Interact::Transport::Telnet::Options'
-        => from 'HashRef[Any]'
-            => via { Net::CLI::Interact::Transport::Telnet::Options->new($_) };
 }
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 # allow native use of Net::Telnet on Unix
-if (not Net::CLI::Interact::Transport::is_win32()) {
-    has '+use_net_telnet_connection' => ( default => 1 );
+if (not Net::CLI::Interact::Transport::Base::is_win32()) {
+    has '+use_net_telnet_connection' => ( default => quote_sub('1') );
 }
 
 has 'connect_options' => (
     is => 'ro',
-    isa => 'Net::CLI::Interact::Transport::Telnet::Options',
-    coerce => 1,
+    isa => InstanceOf['Net::CLI::Interact::Transport::Telnet::Options'],
+    coerce => quote_sub(q{ (ref '' eq ref $_[0]) ? $_[0] :
+        Net::CLI::Interact::Transport::Telnet::Options->new(@_) }),
     required => 1,
 );
 
 sub _build_app {
     my $self = shift;
-    confess "please pass location of plink.exe in 'app' parameter to new()\n"
+    die "please pass location of plink.exe in 'app' parameter to new()\n"
         if $self->is_win32;
-    return 'Net::Telnet'; # unix, but unused
+    return 'telnet';
 }
 
 sub runtime_options {
@@ -68,13 +69,20 @@ sub runtime_options {
             $self->connect_options->host,
         );
     }
-    else {
+    elsif ($self->can_use_pty) {
         return (
             Host => $self->connect_options->host,
             Port => $self->connect_options->port,
             @{$self->connect_options->opts},
         );
     }
+    else {
+        return (
+            @{$self->connect_options->opts},
+            $self->connect_options->host,
+            $self->connect_options->port,
+        );
+    }
 }
 
 1;
@@ -91,9 +99,9 @@ Net::CLI::Interact::Transport::Telnet - TELNET based CLI connection
 
 =head1 VERSION
 
-version 1.122530
+version 2.123300_001
 
-=head1 DECRIPTION
+=head1 DESCRIPTION
 
 This module provides a wrapped instance of a TELNET client for use by
 L<Net::CLI::Interact>.
@@ -130,9 +138,17 @@ If you want to pass any other options to the Telnet application, then use
 this option, which should be an array reference.
 
 On Windows platforms, each item on the list will be passed to the C<plink.exe>
-application, separated by a single space character. On Unix platforms, the
-L<Net::Telnet> library is used for TELNET connections, so the list can be any
-options taken by its C<new()> constructor.
+application, separated by a single space character. On Unix platforms, if depends
+whether you have L<IO::Pty> installed (which in turn depends on a compiler).
+Typically, the L<Net::Telnet> library is used for TELNET connections, so the 
+list can be any options taken by its C<new()> constructor. Otherwise the local
+C<telnet> application is used.
+
+=item reap
+
+Only used on Unix platforms, this installs a signal handler which attempts to
+reap the C<ssh> child process. Pass a true value to enable this feature only
+if you notice zombie processes are being left behind after use.
 
 =back
 
@@ -144,7 +160,7 @@ See the following for further interface details:
 
 =item *
 
-L<Net::CLI::Interact::Transport>
+L<Net::CLI::Interact::Transport::Base>
 
 =back
 
